/* this do file takes the raw OECD data and builds a stata database used in the estimation for
*OECD countries Table 7 panel a and B and Figure 5 and 6.
* Additionaly uses the following escencial data bases 
Indicators_Ifscode

*/
clear all
set more off
pause off

cd "$main\data\OECD_Q"
use "$main\data\Indicators_Ifscode.dta"
keep ifscode lettercode
rename lettercode wdicode
sort ifscode
save ifs_wdi.dta, replace
local vars gdp ur emp /*lf*/
local vars2 hw
foreach v of local vars{
clear all
insheet using `v'_updated.csv, comma
drop in 1/2
drop in 2/2
drop in 3/3
rename v1 period
quietly describe
local N `r(k)'
forval i = 2/`N' {
	local title = v`i' in 1
	local title2 = v`i' in 2/2
	preserve
	drop in 1
	drop in 1
	keep period v`i'
	gen country = "`title'&`title2'"
	split country, p("&", ".")
	

	*capture replace period = subinstr(year,"A1","",.)
	rename v`i' `v'
	
	save temp`i'.dta, replace
	restore
}

clear
gen period = ""
forval i = 2/`N' {
	append using temp`i'.dta
	erase temp`i'.dta
}
destring period, replace
drop country
rename country1 country
rename country2 ifscode
replace ifscode=country3 if country3!="" & (country=="Korea" )
drop if country=="China"
drop country3 
drop country4

replace `v'="" if `v'=="n.a."
destring `v', replace ignore(e)
destring ifscode, replace
gen date=quarterly(period, "yq")
format date %tq
order date period ifscode country `v'
sort ifscode date
save `v'_updated.dta,replace
}

foreach v of local vars2{
clear all
insheet using `v'_updated.csv, comma
drop in 1/2
drop in 2/2
drop in 3/3
rename v1 period
quietly describe
local N `r(k)'
forval i = 2/`N' {
	local title = v`i' in 1
	local title2 = v`i' in 2/2
	preserve
	drop in 1
	drop in 1
	keep period v`i'
	gen country = "`title'&`title2'"
	split country, p("&", ".")
	

	*capture replace period = subinstr(year,"A1","",.)
	rename v`i' `v'
	
	save temp`i'.dta, replace
	restore
}

clear
gen period = ""
forval i = 2/`N' {
	append using temp`i'.dta
	erase temp`i'.dta
}
destring period, replace
drop country
rename country1 country
rename country2 ifscode


replace `v'="" if `v'=="n.a."
destring `v', replace ignore(e)
destring ifscode, replace
gen date=quarterly(period, "yq")
format date %tq
order date period ifscode country `v'
sort ifscode date
save `v'_updated.dta,replace
}




clear all
use "gdp_updated.dta"
merge 1:1 ifscode date using "ur_updated.dta"
drop country5
drop country6
drop _merge
sort country date
merge 1:1 ifscode date using "emp_updated.dta"
drop _merge
sort country date
merge 1:1 ifscode date using "hw_updated.dta"
drop _merge

label var gdp "Gross domestic product, volume, market prices"
label var  ur  "Unemployment rate \ PER CENT"
label var  emp "Total employment \ PERSONS"
*label var lf  "Labour force \ PERSONS"
label var hw "Hours worked per employee, total economy \ HOURS"
sort ifscode
merge m:1 ifscode using "$main\data\ifs_wdi.dta"
drop if date==.
drop _merge
drop country3
order date period ifscode wdicode country gdp ur emp /*lf*/
rename date quarter

***************************************************************
* Data Transformations
***************************************************************



tsset ifscode quarter
drop period


***************************************************************
* Merge in additional data
***************************************************************
sort ifscode quarter
merge 1:1 ifscode quarter using "$main\data\oecd_q_weo.dta"
drop _merge

***************************************************************
* Sample
***************************************************************

* 20 advanced economies (from NBER BLL paper)

local ifsc 193 122 124 156 128 172 132 134 178 136 158 138 196 142 182 184 144 146 112 111
gen ae20 = 0
foreach i of local ifsc{
replace ae20 = 1 if ifscode == `i'
}

keep if ae20==1
drop ae20

* Fill missing wdicodes and country names
sort ifscode quarter
bys ifscode: gen minus_quarter = -1*quarter

sort ifscode quarter
bys ifscode: replace wdicode = wdicode[_n-1] if quarter>=tq(2014Q1)

sort ifscode quarter
bys ifscode: replace country = country[_n-1] if quarter>=tq(2014Q1)


drop minus_quarter

* quarters: start in 1979 to allow 1980 to be first observation for all countries

keep if quarter>=tq(1979Q1)

***************************************************************
* Transform data
***************************************************************

* Log of real GDP
bys ifscode: gen logy =ln(gdp)
bys ifscode: replace logy= logy*100
lab var logy "Log of GDP times 100" 

gen logy_weo =ln(gdp_weo)
replace logy_weo= logy_weo * 100


* Change in ln(GDP)
sort ifscode quarter
bys ifscode: gen y_chg = 100*(ln(gdp/gdp[_n-1]))
lab var y_chg "GDP growth"

* Change in U rate
bys ifscode: gen ur_chg = (ur-ur[_n-1])
lab var ur_chg "Change in unemployment rate"

* Log of employment
bys ifscode: gen ln_emp = ln(emp)
bys ifscode: replace ln_emp = ln_emp*100

bys ifscode: gen ln_emp_weo = ln(emp_weo)
bys ifscode: replace ln_emp_weo = ln_emp_weo*100

* Change in ln(employment)
bys ifscode: gen emp_chg1 = 100*(ln(emp/emp[_n-1]))
lab var emp_chg1 "Employment growth"



***************************************************************
* Splicing data for 2014-18 period using WEO October 2013. 
***************************************************************


lab var logy_weo "Log of GDP times 100. Spliced after 2013 using data from WEO (October 2013)" 

gen aux = logy
replace aux = aux[_n-1] + (logy_weo - logy_weo[_n-1]) if quarter >=tq(2014Q1)

drop logy_weo
rename aux logy_weo
lab var logy_weo "Log of GDP times 100. Spliced after 2013 using data from WEO (October 2013)." 


gen aux = ur
replace aux = aux[_n-1] + (ur_weo - ur_weo[_n-1]) if quarter >=tq(2014Q1)
drop ur_weo
rename aux ur_weo
lab var ur_weo "Unemployment rate. Spliced after 2013 using data from WEO (October 2013)."


gen aux = ln_emp
replace aux = aux[_n-1] + (ln_emp_weo - ln_emp_weo[_n-1]) if quarter >=tq(2014Q1)
drop ln_emp_weo
rename aux ln_emp_weo
lab var ln_emp_weo "Log of employment times 100. Spliced after 2013 using data from WEO (October 2013)." 

***************************************************************
* HP Filtering (lambda = 1000)
***************************************************************

* HP Filtering
* Smoothing factor 1000: GDP
sort ifscode quarter
bys ifscode: hprescott logy, smooth(16000) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_logy_sm_`i' = 0 if H1_logy_sm_`i'==.
}
gen logy_hpf16000 = H1_logy_sm_1
forval i = 2/20 {
	replace logy_hpf16000 = logy_hpf16000 + H1_logy_sm_`i'
}
drop *H1* 
bys ifscode: replace logy_hpf16000=. if logy_hpf16000 ==0
lab var logy_hpf16000 "GDP hp-filtered 16000 factor"

* HP Filtering
* Smoothing factor 1000: UR
sort ifscode quarter
bys ifscode: hprescott ur, smooth(16000) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_ur_sm_`i' = 0 if H1_ur_sm_`i'==.
}
gen ur_hpf16000 = H1_ur_sm_1
forval i = 2/20 {
	replace ur_hpf16000 = ur_hpf16000 + H1_ur_sm_`i'
}
drop *H1* 
bys ifscode: replace ur_hpf16000=. if ur_hpf16000 ==0
rename ur_hpf16000 u_hpf16000
lab var u_hpf16000 "UR hp-filtered 16000 factor"

* HP Filtering
* Smoothing factor 1000: Employment
sort ifscode quarter
bys ifscode: hprescott ln_emp, smooth(16000) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_ln_emp_sm_`i' = 0 if H1_ln_emp_sm_`i'==.
}
gen ln_emp_hpf16000 = H1_ln_emp_sm_1
forval i = 2/20 {
	replace ln_emp_hpf16000 = ln_emp_hpf16000 + H1_ln_emp_sm_`i'
}
drop *H1* 
bys ifscode: replace ln_emp_hpf16000=. if ln_emp_hpf16000 ==0
lab var ln_emp_hpf16000 "Log Employment hp-filtered 16000 factor"

***************************************************************
* HP Filtering (lambda = 100)
***************************************************************

* HP Filtering
* Smoothing factor 100: GDP
sort ifscode quarter
bys ifscode: hprescott logy, smooth(1600) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_logy_sm_`i' = 0 if H1_logy_sm_`i'==.
}
gen logy_hpf1600 = H1_logy_sm_1
forval i = 2/20 {
	replace logy_hpf1600 = logy_hpf1600 + H1_logy_sm_`i'
}
drop *H1* 
bys ifscode: replace logy_hpf1600=. if logy_hpf1600 ==0
lab var logy_hpf1600 "GDP hp-filtered 1600 factor"

* HP Filtering
* Smoothing factor 100: UR
sort ifscode quarter
bys ifscode: hprescott ur, smooth(1600) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_ur_sm_`i' = 0 if H1_ur_sm_`i'==.
}
gen ur_hpf1600 = H1_ur_sm_1
forval i = 2/20 {
	replace ur_hpf1600 = ur_hpf1600 + H1_ur_sm_`i'
}
drop *H1* 
bys ifscode: replace ur_hpf1600=. if ur_hpf1600 ==0
rename ur_hpf1600 u_hpf1600
lab var u_hpf1600 "UR hp-filtered 1600 factor"

* HP Filtering
* Smoothing factor 100: Employment
sort ifscode quarter
bys ifscode: hprescott ln_emp, smooth(1600) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_ln_emp_sm_`i' = 0 if H1_ln_emp_sm_`i'==.
}
gen ln_emp_hpf1600 = H1_ln_emp_sm_1
forval i = 2/20 {
	replace ln_emp_hpf1600 = ln_emp_hpf1600 + H1_ln_emp_sm_`i'
}
drop *H1* 
bys ifscode: replace ln_emp_hpf1600=. if ln_emp_hpf1600 ==0
lab var ln_emp_hpf1600 "Log Employment hp-filtered 1600 factor"

***************************************************************
* HP Filtering and Gaps for Precrisis Sample (up to 2007) 
***************************************************************

bys ifscode: gen logy_2007 = logy if quarter < 2008
lab var logy_2007 "Log of GDP ending in 2007"

bys ifscode: gen u_2007    = ur    if quarter < 2008
lab var u_2007 "UR ending in 2007"

bys ifscode: gen emp_2007    = ln_emp    if quarter < 2008
lab var emp_2007 "Employment ending in 2007"

* lambda = 100

* HP Filtering
* Smoothing factor 100: GDP
sort ifscode quarter
bys ifscode: hprescott logy_2007, smooth(1600) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_logy_2007_sm_`i' = 0 if H1_logy_2007_sm_`i'==.
}
gen logy_2007_hpf1600 = H1_logy_2007_sm_1
forval i = 2/20 {
	replace logy_2007_hpf1600 = logy_2007_hpf1600 + H1_logy_2007_sm_`i'
}
drop *H1* 
bys ifscode: replace logy_2007_hpf1600=. if logy_2007_hpf1600 ==0
rename logy_2007_hpf1600 logy_hpf1600_07
lab var logy_hpf1600_07 "GDP hp-filtered 1600 factor ending in 2007"
sort ifscode quarter
bys ifscode: gen ystar1600 = logy_hpf1600_07-logy_hpf1600_07[_n-1] if quarter==2007
bys ifscode: replace ystar1600 = ystar1600[_n-1] if quarter>=2008
forvalue i=1/6{
	bys ifscode: replace logy_hpf1600_07 = logy_hpf1600_07[_n-1] + ystar1600 if quarter==2007+`i'
	}
drop ystar1600

* HP Filtering
* Smoothing factor 100: UR
sort ifscode quarter
bys ifscode: hprescott u_2007, smooth(1600) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_u_2007_sm_`i' = 0 if H1_u_2007_sm_`i'==.
}
gen u_2007_hpf1600 = H1_u_2007_sm_1
forval i = 2/20 {
	replace u_2007_hpf1600 = u_2007_hpf1600 + H1_u_2007_sm_`i'
}
drop *H1* 
bys ifscode: replace u_2007_hpf1600=. if u_2007_hpf1600 ==0

rename u_2007_hpf1600 u_hpf1600_07
lab var u_hpf1600_07 "UR hp-filtered 1600 factor ending in 2007"
bys ifscode: gen ustar1600 = u_hpf1600_07 if quarter==2007
bys ifscode: replace ustar1600 = ustar1600[_n-1] if quarter>=2008
forvalue i=1/6{
	bys ifscode: replace u_hpf1600_07 = ustar1600 if quarter==2007+`i'
	}
drop ustar1600

* HP Filtering
* Smoothing factor 100: emp
sort ifscode quarter
bys ifscode: hprescott emp_2007, smooth(1600) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_emp_2007_sm_`i' = 0 if H1_emp_2007_sm_`i'==.
}
gen emp_2007_hpf1600 = H1_emp_2007_sm_1
forval i = 2/20 {
	replace emp_2007_hpf1600 = emp_2007_hpf1600 + H1_emp_2007_sm_`i'
}
drop *H1* 
bys ifscode: replace emp_2007_hpf1600=. if emp_2007_hpf1600 ==0
rename emp_2007_hpf1600 ln_emp_hpf1600_07
lab var ln_emp_hpf1600_07 "emp hp-filtered 1600 factor ending in 2007"
sort ifscode quarter
bys ifscode: gen empstar1600 = ln_emp_hpf1600_07-ln_emp_hpf1600_07[_n-1] if quarter==2007
bys ifscode: replace empstar1600 = empstar1600[_n-1] if quarter>=2008
forvalue i=1/6{
	bys ifscode: replace ln_emp_hpf1600_07 = ln_emp_hpf1600_07[_n-1] + empstar1600 if quarter==2007+`i'
	}
drop empstar1600

***************************************************************

* lambda = 1000

* HP Filtering
* Smoothing factor 16000: GDP
sort ifscode quarter
bys ifscode: hprescott logy_2007, smooth(16000) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_logy_2007_sm_`i' = 0 if H1_logy_2007_sm_`i'==.
}
gen logy_2007_hpf16000 = H1_logy_2007_sm_1
forval i = 2/20 {
	replace logy_2007_hpf16000 = logy_2007_hpf16000 + H1_logy_2007_sm_`i'
}
drop *H1* 
bys ifscode: replace logy_2007_hpf16000=. if logy_2007_hpf16000 ==0
rename logy_2007_hpf16000 logy_hpf16000_07
lab var logy_hpf16000_07 "GDP hp-filtered 16000 factor ending in 2007"
sort ifscode quarter
bys ifscode: gen ystar16000 = logy_hpf16000_07-logy_hpf16000_07[_n-1] if quarter==2007
bys ifscode: replace ystar16000 = ystar16000[_n-1] if quarter>=2008
forvalue i=1/6{
	bys ifscode: replace logy_hpf16000_07 = logy_hpf16000_07[_n-1] + ystar16000 if quarter==2007+`i'
	}
drop ystar16000

* HP Filtering
* Smoothing factor 1000: UR
sort ifscode quarter
bys ifscode: hprescott u_2007, smooth(16000) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_u_2007_sm_`i' = 0 if H1_u_2007_sm_`i'==.
}
gen u_2007_hpf16000 = H1_u_2007_sm_1
forval i = 2/20 {
	replace u_2007_hpf16000 = u_2007_hpf16000 + H1_u_2007_sm_`i'
}
drop *H1* 
bys ifscode: replace u_2007_hpf16000=. if u_2007_hpf16000 ==0

rename u_2007_hpf16000 u_hpf16000_07
lab var u_hpf16000_07 "UR hp-filtered 16000 factor ending in 2007"
bys ifscode: gen ustar16000 = u_hpf16000_07 if quarter==2007
bys ifscode: replace ustar16000 = ustar16000[_n-1] if quarter>=2008
forvalue i=1/6{
	bys ifscode: replace u_hpf16000_07 = ustar16000 if quarter==2007+`i'
	}
drop ustar16000

* HP Filtering
* Smoothing factor 1000: emp
sort ifscode quarter
bys ifscode: hprescott emp_2007, smooth(16000) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_emp_2007_sm_`i' = 0 if H1_emp_2007_sm_`i'==.
}
gen emp_2007_hpf16000 = H1_emp_2007_sm_1
forval i = 2/20 {
	replace emp_2007_hpf16000 = emp_2007_hpf16000 + H1_emp_2007_sm_`i'
}
drop *H1* 
bys ifscode: replace emp_2007_hpf16000=. if emp_2007_hpf16000 ==0
rename emp_2007_hpf16000 ln_emp_hpf16000_07
lab var ln_emp_hpf16000_07 "emp hp-filtered 16000 factor ending in 2007"
sort ifscode quarter
bys ifscode: gen empstar16000 = ln_emp_hpf16000_07-ln_emp_hpf16000_07[_n-1] if quarter==2007
bys ifscode: replace empstar16000 = empstar16000[_n-1] if quarter>=2008
forvalue i=1/6{
	bys ifscode: replace ln_emp_hpf16000_07 = ln_emp_hpf16000_07[_n-1] + empstar16000 if quarter==2007+`i'
	}
drop empstar16000

***************************************************************
* HP Filtering (lambda = 100).  WEO forecasts through 2018.
***************************************************************

* HP Filtering
* Smoothing factor 100: GDP
sort ifscode quarter
bys ifscode: hprescott logy_weo, smooth(1600) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_logy_weo_sm_`i' = 0 if H1_logy_weo_sm_`i'==.
}
gen logy_weo_hpf1600 = H1_logy_weo_sm_1
forval i = 2/20 {
	replace logy_weo_hpf1600 = logy_weo_hpf1600 + H1_logy_weo_sm_`i'
}
drop *H1* 
bys ifscode: replace logy_weo_hpf1600=. if logy_weo_hpf1600 ==0
lab var logy_weo_hpf1600 "GDP hp-filtered 1600 factor. WEO forecasts through 2018."

* HP Filtering
* Smoothing factor 100: ur_weo
sort ifscode quarter
bys ifscode: hprescott ur_weo, smooth(1600) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_ur_weo_sm_`i' = 0 if H1_ur_weo_sm_`i'==.
}
gen ur_weo_hpf1600 = H1_ur_weo_sm_1
forval i = 2/20 {
	replace ur_weo_hpf1600 = ur_weo_hpf1600 + H1_ur_weo_sm_`i'
}
drop *H1* 
bys ifscode: replace ur_weo_hpf1600=. if ur_weo_hpf1600 ==0
rename ur_weo_hpf1600 u_weo_hpf1600
lab var u_weo_hpf1600 "UR hp-filtered 1600 factor. WEO forecasts through 2018."

* HP Filtering
* Smoothing factor 100: ln(emp)
sort ifscode quarter
bys ifscode: hprescott ln_emp_weo, smooth(1600) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_ln_emp_weo_sm_`i' = 0 if H1_ln_emp_weo_sm_`i'==.
}
gen ln_emp_weo_hpf1600 = H1_ln_emp_weo_sm_1
forval i = 2/20 {
	replace ln_emp_weo_hpf1600 = ln_emp_weo_hpf1600 + H1_ln_emp_weo_sm_`i'
}
drop *H1* 
bys ifscode: replace ln_emp_weo_hpf1600=. if ln_emp_weo_hpf1600 ==0
lab var ln_emp_weo_hpf1600 "Log Employment hp-filtered 1600 factor. WEO forecasts through 2018."

***************************************************************
* HP Filtering (lambda = 1000).  WEO forecasts through 2018.
***************************************************************

* HP Filtering
* Smoothing factor 1000: GDP
sort ifscode quarter
bys ifscode: hprescott logy_weo, smooth(16000) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_logy_weo_sm_`i' = 0 if H1_logy_weo_sm_`i'==.
}
gen logy_weo_hpf16000 = H1_logy_weo_sm_1
forval i = 2/20 {
	replace logy_weo_hpf16000 = logy_weo_hpf16000 + H1_logy_weo_sm_`i'
}
drop *H1* 
bys ifscode: replace logy_weo_hpf16000=. if logy_weo_hpf16000 ==0
lab var logy_weo_hpf16000 "GDP hp-filtered 16000 factor. WEO forecasts through 2018."

* HP Filtering
* Smoothing factor 1000: ur_weo
sort ifscode quarter
bys ifscode: hprescott ur_weo, smooth(16000) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_ur_weo_sm_`i' = 0 if H1_ur_weo_sm_`i'==.
}
gen ur_weo_hpf16000 = H1_ur_weo_sm_1
forval i = 2/20 {
	replace ur_weo_hpf16000 = ur_weo_hpf16000 + H1_ur_weo_sm_`i'
}
drop *H1* 
bys ifscode: replace ur_weo_hpf16000=. if ur_weo_hpf16000 ==0
rename ur_weo_hpf16000 u_weo_hpf16000
lab var u_weo_hpf16000 "UR hp-filtered 16000 factor. WEO forecasts through 2018."

* HP Filtering
* Smoothing factor 1000: ln(emp)
sort ifscode quarter
bys ifscode: hprescott ln_emp_weo, smooth(16000) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_ln_emp_weo_sm_`i' = 0 if H1_ln_emp_weo_sm_`i'==.
}
gen ln_emp_weo_hpf16000 = H1_ln_emp_weo_sm_1
forval i = 2/20 {
	replace ln_emp_weo_hpf16000 = ln_emp_weo_hpf16000 + H1_ln_emp_weo_sm_`i'
}
drop *H1* 
bys ifscode: replace ln_emp_weo_hpf16000=. if ln_emp_weo_hpf16000 ==0
lab var ln_emp_weo_hpf16000 "Log Employment hp-filtered 16000 factor. WEO forecasts through 2018."

***************************************************************
* Gaps
***************************************************************

* lambda = 100
bys ifscode: gen u_star1600 = ur - u_hpf1600
lab var u_star1600 " U minus U hpf1600"
bys ifscode: gen y_star1600 = logy - logy_hpf1600 
lab var y_star1600 " Y minus Y hpf1600"
bys ifscode: gen emp_star1600 = ln_emp - ln_emp_hpf1600
lab var emp_star1600 "log emp minus emp hpf1600"  

bys ifscode: gen u_star1600_07=ur-u_hpf1600_07
lab var u_star1600_07 " U minus U hpf1600_07"
bys ifscode: gen y_star1600_07 = logy - logy_hpf1600_07
lab var y_star1600_07 "Y minus Y hpf1600_07"
bys ifscode: gen emp_star1600_07 = ln_emp - ln_emp_hpf1600_07
lab var emp_star1600_07 "log emp minus emp hpf1600_07"

bys ifscode: gen u_weo_star1600 = ur_weo - u_weo_hpf1600
lab var u_weo_star1600 " U minus U hpf1600. WEO forecasts through 2018."
bys ifscode: gen y_weo_star1600 = logy_weo - logy_weo_hpf1600 
lab var y_weo_star1600 "Y minus Y hpf1600. WEO forecasts through 2018."
bys ifscode: gen emp_weo_star1600 = ln_emp_weo - ln_emp_weo_hpf1600
lab var emp_weo_star1600 "log emp minus emp hpf1600. WEO forecasts through 2018."

* lambda = 1000
bys ifscode: gen u_star16000 = ur - u_hpf16000
lab var u_star16000 " U minus U hpf16000"
bys ifscode: gen y_star16000 = logy - logy_hpf16000 
lab var y_star16000 "Y minus Y hpf16000"
bys ifscode: gen emp_star16000 = ln_emp - ln_emp_hpf16000
lab var emp_star16000 "log emp minus emp hpf16000"

bys ifscode: gen u_star16000_07=ur-u_hpf16000_07
lab var u_star16000_07 " U minus U hpf16000_07"
bys ifscode: gen y_star16000_07 = logy - logy_hpf16000_07
lab var y_star16000_07 "Y minus Y hpf16000_07"
bys ifscode: gen emp_star16000_07 = ln_emp - ln_emp_hpf16000_07
lab var emp_star16000_07 "log emp minus emp hpf16000_07"

bys ifscode: gen u_weo_star16000 = ur_weo - u_weo_hpf16000
lab var u_weo_star16000 " U minus U hpf16000. WEO forecasts through 2018."
bys ifscode: gen y_weo_star16000 = logy_weo - logy_weo_hpf16000 
lab var y_weo_star16000 "Y minus Y hpf16000. WEO forecasts through 2018."
bys ifscode: gen emp_weo_star16000 = ln_emp_weo - ln_emp_weo_hpf16000
lab var emp_weo_star16000 "log emp minus emp hpf16000. WEO forecasts through 2018."

***************************************************************
* Save after dropping excess quarters
***************************************************************

* 1979 - 2013
* (start in 1979 to allow 1980 to be first observation for first differences)

keep if (quarter>=tq(1979q1) & quarter<=tq(2013Q4))

save "$main\data\oecd_q_transformed_updated", replace





