*Note Nathalie: This file takes the data in "Data_USA_FRED_updated.csv" and generates the varaibles neede for estimating the Okun's Law.
*In particlar it estiamtes the Y* and U* using hoddrick prescot con lamda = 100 and = 1000 and the changes versions.
***********a****************************************************
* Data Transformations
***************************************************************
*global main= "Q:\DATA\Okun\other\data_appendix"

cd "$main\data"
set more off
clear

insheet using Data_USA_FRED_updated.csv,comma
label var gdp "Real Gross Domestic Product, Billions of Chained 2009 Dollars"
label var ur "Civilian Unemployment Rate, Percent"
label var emp1 "Civilian Employment, Thousands of Persons"
label var emp2 "All Employees: Total nonfarm, Thousands of Persons"
label var pop1 "Total Population: All Ages including Armed Forces Overseas, Thousands"
label var pop2 "Working Age Population: Aged 15 and Over: All Persons for the United States, Source:OECD"
label var hw "Nonfarm Business Sector: Average Weekly Hours"

rename date year

tsset year

***************************************************************
* Transform data
***************************************************************
* Log of real GDP
gen logy =log(gdp)
replace logy= logy * 100
lab var logy "Log of GDP times 100" 
/*
gen logy_weo =log(weo_gdp)
replace logy_weo= logy_weo * 100
lab var logy_weo "Log of GDP times 100. Source: WEO (October 2013)" 
*/
* Change in ln(GDP)
sort year
gen y_chg = 100*(ln(gdp/gdp[_n-1]))
lab var y_chg "GDP growth"

* Change in U rate
gen ur_chg = (ur-ur[_n-1])
lab var ur_chg "Change in unemployment rate"




***************************************************************
* HP Filtering (lambda = 1000)
***************************************************************

* HP Filtering
* Smoothing factor 1000: GDP
sort year
hprescott logy, smooth(1000) stub(H1)
gen logy_hpf1000 = H1_logy_sm_1
drop *H1* 
replace logy_hpf1000=. if logy_hpf1000 ==0
lab var logy_hpf1000 "GDP hp-filtered 1000 factor"

* HP Filtering
* Smoothing factor 1000: UR
hprescott ur, smooth(1000) stub(H1)
gen u_hpf1000 = H1_ur_sm_1
drop *H1* 
replace u_hpf1000=. if u_hpf1000 ==0
lab var u_hpf1000 "UR hp-filtered 1000 factor"




***************************************************************
* HP Filtering (lambda = 100)
***************************************************************

* HP Filtering
* Smoothing factor 100: GDP
sort year
hprescott logy, smooth(100) stub(H1)
gen logy_hpf100 = H1_logy_sm_1
drop *H1* 
replace logy_hpf100=. if logy_hpf100 ==0
lab var logy_hpf100 "GDP hp-filtered 100 factor"

* HP Filtering
* Smoothing factor 100: UR
hprescott ur, smooth(100) stub(H1)
gen u_hpf100 = H1_ur_sm_1
drop *H1* 
replace u_hpf100=. if u_hpf100 ==0
lab var u_hpf100 "UR hp-filtered 100 factor"



***************************************************************
* HP Filtering and Gaps for Precrisis Sample (up to 2007) 
***************************************************************

gen logy_2007 = logy if year < 2008
lab var logy_2007 "Log of GDP ending in 2007"

gen u_2007    = ur    if year < 2008
lab var u_2007 "UR ending in 2007"



* HP Filtering
* Smoothing factor 1000: GDP

hprescott logy_2007, smooth(1000) stub(H1)
gen logy_hpf1000_07 = H1_logy_2007_sm_1
drop *H1* 
replace logy_hpf1000_07=. if logy_hpf1000_07 ==0
lab var logy_hpf1000_07 "GDP hp-filtered 1000 factor ending in 2007"
sort year
gen ystar1000 = logy_hpf1000_07-logy_hpf1000_07[_n-1] if year==2007
replace ystar1000 = ystar1000[_n-1] if year>=2008
forvalue i=1/6{
	replace logy_hpf1000_07 = logy_hpf1000_07[_n-1] + ystar1000 if year==2007+`i'
	}
drop ystar1000

* HP Filtering
* Smoothing factor 1000: UR

hprescott u_2007, smooth(1000) stub(H1)
gen u_hpf1000_07 = H1_u_2007_sm_1
drop *H1* 
replace u_hpf1000_07=. if u_hpf1000_07 ==0
lab var u_hpf1000_07 "UR hp-filtered 1000 factor ending in 2007"
gen ustar1000 = u_hpf1000_07 if year==2007
replace ustar1000 = ustar1000[_n-1] if year>=2008
forvalue i=1/6{
	replace u_hpf1000_07 = ustar1000 if year==2007+`i'
	}
drop ustar1000


* HP Filtering
* Smoothing factor 100: GDP

hprescott logy_2007, smooth(100) stub(H1)
gen logy_hpf100_07 = H1_logy_2007_sm_1
drop *H1* 
replace logy_hpf100_07=. if logy_hpf100_07 ==0
lab var logy_hpf100_07 "GDP hp-filtered 100 factor ending in 2007"
gen ystar100 = logy_hpf100_07-logy_hpf100_07[_n-1] if year==2007
replace ystar100 = ystar100[_n-1] if year>=2008
forvalue i=1/6{
	replace logy_hpf100_07 = logy_hpf100_07[_n-1] + ystar100 if year==2007+`i'
	}
drop ystar100

* HP Filtering
* Smoothing factor 100: UR

hprescott u_2007, smooth(100) stub(H1)
gen u_hpf100_07 = H1_u_2007_sm_1
drop *H1* 
replace u_hpf100_07=. if u_hpf100_07 ==0
lab var u_hpf100_07 "UR hp-filtered 100 factor ending in 2007"
gen ustar100 = u_hpf100_07 if year==2007
replace ustar100 = ustar100[_n-1] if year>=2008
forvalue i=1/6{
	replace u_hpf100_07 = ustar100 if year==2007+`i'
	}
drop ustar100




***************************************************************
* Gaps
***************************************************************

* lambda = 1000
gen u_star1000 = ur - u_hpf1000
lab var u_star1000 " U minus U HPF1000"
gen y_star1000 = logy - logy_hpf1000 
lab var y_star1000 "Y minus Y HPF1000"

gen u_star1000_07=ur-u_hpf1000_07
lab var u_star1000_07 " U minus U HPF1000_07"
gen y_star1000_07 = logy - logy_hpf1000_07
lab var y_star1000_07 "Y minus Y HPF1000_07"


* lambda = 100
gen u_star100 = ur - u_hpf100
lab var u_star100 " U minus U HPF100"
gen y_star100 = logy - logy_hpf100 
lab var y_star100 " Y minus Y HPF100"


gen u_star100_07=ur-u_hpf100_07
lab var u_star100_07 " U minus U HPF100_07"
gen y_star100_07 = logy - logy_hpf100_07
lab var y_star100_07 "Y minus Y HPF100_07"



save "usa_a_transformed_updated", replace



