***************************************************************
* Data Transformations
***************************************************************
clear all
set more off

cd "$main\data"
insheet using Data_USA_FRED_updatedQ.csv,comma
label var gdp "Real Gross Domestic Product, Billions of Chained 2009 Dollars"
label var ur "Civilian Unemployment Rate, Percent"
label var emp1 "Civilian Employment, Thousands of Persons"
label var emp2 "All Employees: Total nonfarm, Thousands of Persons"
label var pop1 "Total Population: All Ages including Armed Forces Overseas, Thousands"
label var pop2 "Working Age Population: Aged 15 and Over: All Persons for the United States, Source:OECD"
label var hw "Nonfarm Business Sector: Average Weekly Hours"
gen date2=quarterly(date, "yq")
rename date period
rename date2 date
format date %tq

order date period gdp ur emp* pop*

rename date quarter

tsset quarter


preserve
clear
use nber_recessions
gen time = quarterly(quarter, "YQ")
format time %tq
drop quarter
rename time quarter
sort quarter
tempfile temp
save `temp', replace
restore
sort quarter
merge quarter using `temp'
drop _merge

drop quarter_number year period



***************************************************************
* Transform data
***************************************************************
* Log of real GDP
gen logy =log(gdp)
replace logy= logy * 100
lab var logy "Log of GDP times 100" 

* Change in ln(GDP)
sort quarter
gen y_chg = 100*(ln(gdp/gdp[_n-1]))
lab var y_chg "GDP growth"

* Change in U rate
gen ur_chg = (ur-ur[_n-1])
lab var ur_chg "Change in unemployment rate"

* Log of employment
gen ln_emp1 = ln(emp1)
replace ln_emp1 = ln_emp1*100

gen ln_emp2 = ln(emp2)
replace ln_emp2 = ln_emp2*100

* Change in ln(employment)
gen emp_chg1 = 100*(ln(emp1/emp1[_n-1]))
lab var emp_chg1 "Employment growth (Household Survey)"

gen emp_chg2 = 100*(ln(emp2/emp2[_n-1]))
lab var emp_chg2 "Employment growth (All employees)"

***************************************************************
* HP Filtering (lambda = 1600)
***************************************************************

* HP Filtering
* Smoothing factor 1600: GDP
sort quarter
hprescott logy, smooth(1600) stub(H1)
gen logy_hpf1600 = H1_logy_sm_1
drop *H1* 
replace logy_hpf1600=. if logy_hpf1600 ==0
lab var logy_hpf1600 "GDP hp-filtered 1600 factor"

* HP Filtering
* Smoothing factor 1600: UR
hprescott ur, smooth(1600) stub(H1)
gen u_hpf1600 = H1_ur_sm_1
drop *H1* 
replace u_hpf1600=. if u_hpf1600 ==0
lab var u_hpf1600 "UR hp-filtered 1600 factor"

* HP Filtering
* Smoothing factor 1600: ln(emp)
hprescott ln_emp1, smooth(1600) stub(H1)
gen ln_emp1_hpf1600 = H1_ln_emp1_sm_1
drop *H1* 
replace ln_emp1_hpf1600=. if ln_emp1_hpf1600 ==0
lab var ln_emp1_hpf1600 "Log Employment hp-filtered 1600 factor (Household Survey)"
hprescott ln_emp2, smooth(1600) stub(H1)
gen ln_emp2_hpf1600 = H1_ln_emp2_sm_1
drop *H1* 
replace ln_emp2_hpf1600=. if ln_emp2_hpf1600 ==0
lab var ln_emp2_hpf1600 "Log Employment hp-filtered 1600 factor (All Emp.)"

***************************************************************
* HP Filtering (lambda = 16000)
***************************************************************

* HP Filtering
* Smoothing factor 16000: GDP
sort quarter
hprescott logy, smooth(16000) stub(H1)
gen logy_hpf16000 = H1_logy_sm_1
drop *H1* 
replace logy_hpf16000=. if logy_hpf16000 ==0
lab var logy_hpf16000 "GDP hp-filtered 16000 factor"

* HP Filtering
* Smoothing factor 16000: UR
hprescott ur, smooth(16000) stub(H1)
gen u_hpf16000 = H1_ur_sm_1
drop *H1* 
replace u_hpf16000=. if u_hpf16000 ==0
lab var u_hpf16000 "UR hp-filtered 16000 factor"

* HP Filtering
* Smoothing factor 16000: ln(emp)
hprescott ln_emp1, smooth(16000) stub(H1)
gen ln_emp1_hpf16000 = H1_ln_emp1_sm_1
drop *H1* 
replace ln_emp1_hpf16000=. if ln_emp1_hpf16000 ==0
lab var ln_emp1_hpf16000 "Log Employment hp-filtered 16000 factor (Household Survey)"
hprescott ln_emp2, smooth(16000) stub(H1)
gen ln_emp2_hpf16000 = H1_ln_emp2_sm_1
drop *H1* 
replace ln_emp2_hpf16000=. if ln_emp2_hpf1600 ==0
lab var ln_emp2_hpf16000 "Log Employment hp-filtered 16000 factor (All Emp.)"

***************************************************************
* HP Filtering and Gaps for Precrisis Sample (up to 2007) 
***************************************************************

gen logy_2007 = logy if quarter < tq(2007Q4)
lab var logy_2007 "Log of GDP ending in 2007"

gen u_2007    = ur    if quarter < tq(2007Q4)
lab var u_2007 "UR ending in 2007"

gen emp1_2007    = ln_emp1    if quarter < tq(2007Q4)
lab var emp1_2007 "Employment (Household Survey) ending in 2007"

gen emp2_2007    = ln_emp2    if quarter < tq(2007Q4)
lab var emp2_2007 "Employment (all) ending in 2007"

***************************************************************

* lambda = 1600

* HP Filtering
* Smoothing factor 1600: GDP

hprescott logy_2007, smooth(1600) stub(H1)
gen logy_hpf1600_07 = H1_logy_2007_sm_1
drop *H1* 
replace logy_hpf1600_07=. if logy_hpf1600_07 ==0
lab var logy_hpf1600_07 "GDP hp-filtered 100 factor ending in 2007"
gen ystar1600 = logy_hpf1600_07-logy_hpf1600_07[_n-1] if quarter==tq(2007Q3)
replace ystar1600 = ystar1600[_n-1] if quarter>=tq(2007Q4)
forvalue i=1/24{
	replace logy_hpf1600_07 = logy_hpf1600_07[_n-1] + ystar1600 if quarter==tq(2007Q3)+`i'
	}
drop ystar1600

* HP Filtering
* Smoothing factor 1600: UR

hprescott u_2007, smooth(1600) stub(H1)
gen u_hpf1600_07 = H1_u_2007_sm_1
drop *H1* 
replace u_hpf1600_07=. if u_hpf1600_07 ==0
lab var u_hpf1600_07 "UR hp-filtered 100 factor ending in 2007"
gen ustar1600 = u_hpf1600_07 if quarter==tq(2007Q3)
replace ustar1600 = ustar1600[_n-1] if quarter>=tq(2007Q4)
forvalue i=1/24{
	replace u_hpf1600_07 = ustar1600 if quarter==tq(2007Q3)+`i'
	}
drop ustar1600

* HP Filtering
* Smoothing factor 1600: EMP1 (Household Survey)

hprescott emp1_2007, smooth(1600) stub(H1)
gen ln_emp1_hpf1600_07 = H1_emp1_2007_sm_1
drop *H1* 
replace ln_emp1_hpf1600_07=. if ln_emp1_hpf1600_07 ==0
lab var ln_emp1_hpf1600_07 "EMP1 (Household Survey) hp-filtered 100 factor ending in 2007"
gen emp1star1600 = ln_emp1_hpf1600_07-ln_emp1_hpf1600_07[_n-1] if quarter==tq(2007Q3)
replace emp1star1600 = emp1star1600[_n-1] if quarter>=tq(2007Q4)
forvalue i=1/24{
	replace ln_emp1_hpf1600_07=ln_emp1_hpf1600_07[_n-1] + emp1star1600 if quarter==tq(2007Q3)+`i'
	}
drop emp1star1600

* HP Filtering
* Smoothing factor 1600: EMP2 (All)

hprescott emp2_2007, smooth(1600) stub(H1)
gen ln_emp2_hpf1600_07 = H1_emp2_2007_sm_1
drop *H1* 
replace ln_emp2_hpf1600_07=. if ln_emp2_hpf1600_07 ==0
lab var ln_emp2_hpf1600_07 "EMP2 (All) hp-filtered 100 factor ending in 2007"
gen emp2star1600 = ln_emp2_hpf1600_07-ln_emp2_hpf1600_07[_n-1] if quarter==tq(2007Q3)
replace emp2star1600 = emp2star1600[_n-1] if quarter>=tq(2007Q4)
forvalue i=1/24{
	replace ln_emp2_hpf1600_07=ln_emp2_hpf1600_07[_n-1] + emp2star1600 if quarter==tq(2007Q3)+`i'
	}
drop emp2star1600

***************************************************************

* lambda = 16000

* HP Filtering
* Smoothing factor 16000: GDP

hprescott logy_2007, smooth(16000) stub(H1)
gen logy_hpf16000_07 = H1_logy_2007_sm_1
drop *H1* 
replace logy_hpf16000_07=. if logy_hpf16000_07 ==0
lab var logy_hpf16000_07 "GDP hp-filtered 1000 factor ending in 2007"
sort quarter
gen ystar16000 = logy_hpf16000_07-logy_hpf16000_07[_n-1] if quarter==tq(2007Q3)
replace ystar16000 = ystar16000[_n-1] if quarter>= tq(2007Q4)
forvalue i=1/24{
	replace logy_hpf16000_07 = logy_hpf16000_07[_n-1] + ystar16000 if quarter==tq(2007Q3)+`i'
	}
drop ystar16000

* HP Filtering
* Smoothing factor 16000: UR

hprescott u_2007, smooth(16000) stub(H1)
gen u_hpf16000_07 = H1_u_2007_sm_1
drop *H1* 
replace u_hpf16000_07=. if u_hpf16000_07 ==0
lab var u_hpf16000_07 "UR hp-filtered 1000 factor ending in 2007"
gen ustar16000 = u_hpf16000_07 if quarter==tq(2007Q3)
replace ustar16000 = ustar16000[_n-1] if quarter>=tq(2007Q4)
forvalue i=1/24{
	replace u_hpf16000_07 = ustar16000 if quarter==tq(2007Q3)+`i'
	}
drop ustar16000

* HP Filtering
* Smoothing factor 16000: EMP1 (Household Survey)

hprescott emp1_2007, smooth(16000) stub(H1)
gen ln_emp1_hpf16000_07 = H1_emp1_2007_sm_1
drop *H1* 
replace ln_emp1_hpf16000_07=. if ln_emp1_hpf16000_07 ==0
lab var ln_emp1_hpf16000_07 "EMP1 (Household Survey) hp-filtered 1000 factor ending in 2007"
gen emp1star16000 = ln_emp1_hpf16000_07-ln_emp1_hpf16000_07[_n-1] if quarter==tq(2007Q3)
replace emp1star16000 = emp1star16000[_n-1] if quarter>=tq(2007Q4)
forvalue i=1/24{
	replace ln_emp1_hpf16000_07=ln_emp1_hpf16000_07[_n-1] + emp1star16000 if quarter==tq(2007Q3)+`i'
	}
drop emp1star16000

* HP Filtering
* Smoothing factor 16000: EMP2 (All)

hprescott emp2_2007, smooth(16000) stub(H1)
gen ln_emp2_hpf16000_07 = H1_emp2_2007_sm_1
drop *H1* 
replace ln_emp2_hpf16000_07=. if ln_emp2_hpf16000_07 ==0
lab var ln_emp2_hpf16000_07 "EMP2 (All) hp-filtered 1000 factor ending in 2007"
gen emp2star16000 = ln_emp2_hpf16000_07-ln_emp2_hpf16000_07[_n-1] if quarter==tq(2007Q3)
replace emp2star16000 = emp2star16000[_n-1] if quarter>=tq(2007Q4)
forvalue i=1/24{
	replace ln_emp2_hpf16000_07=ln_emp2_hpf16000_07[_n-1] + emp2star16000 if quarter==tq(2007Q3)+`i'
	}
drop emp2star16000


***************************************************************
* Gaps
***************************************************************

* lambda = 1600
gen u_star1600 = ur - u_hpf1600
lab var u_star1600 " U minus U HPF1600"
gen y_star1600 = logy - logy_hpf1600 
lab var y_star1600 " Y minus Y HPF1600"
gen emp1_star1600 = ln_emp1 - ln_emp1_hpf1600
lab var emp1_star1600 "log emp1 minus emp1 HPF1600"  
gen emp2_star1600 = ln_emp2 - ln_emp2_hpf1600
lab var emp2_star1600 "log emp2 minus emp2 HPF1600"  

gen u_star1600_07=ur-u_hpf1600_07
lab var u_star1600_07 " U minus U HPF1600_07"
gen y_star1600_07 = logy - logy_hpf1600_07
lab var y_star1600_07 "Y minus Y HPF1600_07"
gen emp1_star1600_07 = ln_emp1 - ln_emp1_hpf1600_07
lab var emp1_star1600_07 "log emp1 minus emp1 HPF1600_07"
gen emp2_star1600_07 = ln_emp2 - ln_emp2_hpf1600_07
lab var emp2_star1600_07 "log emp2 minus emp2 HPF1600_07"

* lambda = 16000
gen u_star16000 = ur - u_hpf16000
lab var u_star16000 " U minus U HPF16000"
gen y_star16000 = logy - logy_hpf16000 
lab var y_star16000 "Y minus Y HPF16000"
gen emp1_star16000 = ln_emp1 - ln_emp1_hpf16000
lab var emp1_star16000 "log emp1 minus emp1 HPF16000"
gen emp2_star16000 = ln_emp2 - ln_emp2_hpf16000
lab var emp2_star16000 "log emp2 minus emp2 HPF16000"

gen u_star16000_07=ur-u_hpf16000_07
lab var u_star16000_07 " U minus U HPF16000_07"
gen y_star16000_07 = logy - logy_hpf16000_07
lab var y_star16000_07 "Y minus Y HPF16000_07"
gen emp1_star16000_07 = ln_emp1 - ln_emp1_hpf16000_07
lab var emp1_star16000_07 "log emp1 minus emp1 HPF16000_07"
gen emp2_star16000_07 = ln_emp2 - ln_emp2_hpf16000_07
lab var emp2_star16000_07 "log emp2 minus emp2 HPF16000_07"

save "usa_q_transformed_updated", replace




