********************************************
* Analysis of Okun's Law
* Contact: Daniel Leigh
********************************************

********************************************
* Read in data
********************************************

set more off
clear
clear matrix
cd "$main\data"
use usa_a_transformed_updated.dta,clear
cd "$main\outputs"

***************************
* (U-U*) vs. (Y-Y*)
* lambda = 100
***************************

preserve
local graphindex = 1
* Variables
cap drop y
cap drop x
gen y = u_star100
gen x = y_star100
* Regression and fitted values
reg y x, noconstant
local n = e(N)
local l = `n'^(1/4)
local l = round(`l')
newey y x, noconstant lag(`l')
* Chart
local ytitle = "{it:U} {subscript:t} - {it:U} * {subscript:t}"
local xtitle = "{it:Y} {subscript:t} - {it:Y} * {subscript:t}"
twoway ///
(lfit y x, lwidth(thin) lcolor(black) lpattern(dash)) ///
(scatter y x, msymbol(Oh) mcolor(black) msize(small) mlabel(year) mlabcolor(black) ///
legend(off) title("`title'") ytitle("`ytitle'") xtitle("`xtitle'") ///
ysize(4) xsize(9.0) ///
plotregion(fcolor(white))  ///
saving(Figure_1A, replace))
restore

***************************
* (U-U*) vs. (Y-Y*)
* lambda = 1,000
***************************

preserve
local graphindex = 2
* Variables
cap drop y
cap drop x
gen y = u_star1000
gen x = y_star1000
* Regression and fitted values
reg y x, noconstant
local n = e(N)
local l = `n'^(1/4)
local l = round(`l')
newey y x, noconstant lag(`l')
* Chart
local ytitle = "{it:U} {subscript:t} - {it:U} * {subscript:t}"
local xtitle = "{it:Y} {subscript:t} - {it:Y} * {subscript:t}"
twoway ///
(lfit y x, lwidth(thin) lcolor(black) lpattern(dash)) ///
(scatter y x, msymbol(Oh) mcolor(black) msize(small) mlabel(year) mlabcolor(black) ///
legend(off) title("`title'") ytitle("`ytitle'") xtitle("`xtitle'") ///
ysize(4) xsize(9.0) ///
plotregion(fcolor(white))  ///
saving(Figure_1B, replace))
restore

***************************
* Actual vs. fitted D(E)
***************************

preserve
local graphindex = 3
* Variables
cap drop y
cap drop x
gen y = ur_chg
gen x = y_chg
* Regression and fitted values
reg y x
local n = e(N)
local l = `n'^(1/4)
local l = round(`l')
newey y x, lag(`l')
* Chart
local ytitle = "{&Delta} {it:U} {subscript:t}"
local xtitle = "{&Delta} {it:Y} {subscript:t}"
twoway ///
(lfit y x, lwidth(thin) lcolor(black) lpattern(dash)) ///
(scatter y x, msymbol(Oh) mcolor(black) msize(small) mlabel(year) mlabcolor(black) ///
legend(off) title("`title'") ytitle("`ytitle'") xtitle("`xtitle'") ///
ysize(4) xsize(9.0) ///
plotregion(fcolor(white))  ///
saving(Figure_1C, replace))
restore
