********************************************
* Analysis of Okun's Law
* comparison Old vs New Recoveries
*Are the new recoveries jobless?
*Last modification: Nathalie Gonzalez
********************************************

********************************************
* Read in data
********************************************
global main = "Q:\DATA\Okun\other\1.data_appendix"
set more off
clear all
clear matrix
cd "$main\data"
use usa_q_transformed_updated.dta,clear
cd "$main\outputs"
keep if quarter <= tq(2013q4)

*********************************************************************************************************************************************************************
*************************************************Alternative graph Average*******************************************************************************************
*********************************************************************************************************************************************************************
*In this new version each point in the graph would contain the average of 4 periods, current and three previous


preserve
* Variables
cap drop y
cap drop x
gen lab_q = "02Q4" if 	quarter== tq(2002q4) 
replace lab_q = "92Q1" if	quarter== tq(1992q1) 
replace lab_q = "10Q2" if quarter== tq(2010q2) 
gen y = emp_chg1
gen x = y_chg
sort quarter
gen L1x = x[_n-1]
gen L2x = x[_n-2]
* Regression and fitted values
reg y x L1x L2x
local n = e(N)
local l = `n'^(1/4)
local l = round(`l')
newey y x L1x L2x,  lag(`l')  
predict yhat
tssmooth ma  y_ma = y if quarter>=tq(1949q4), window(3 1 0)
tssmooth ma  yhat_ma = yhat if quarter>=tq(1949q4) , window(3 1 0)
gen end_recovery_old = quarter== tq(1950q4) | 	quarter== tq(1955q2) | 	quarter== tq(1959q2) ///
| quarter== tq(1962q1) | 	quarter== tq(1971q4) | 	quarter== tq(1976q1) | 	quarter== tq(1981q3) ///
| quarter== tq(1983q4) 
gen end_recovery_new=	quarter== tq(1992q1) | 	quarter== tq(2002q4) | 	quarter== tq(2010q2) 
local ytitle = "Actual {&Delta} {it:E} {subscript:t} (four quarter moving average)"
local xtitle = "Fitted {&Delta} {it:E} {subscript:t} (four quarter moving average)"


twoway (lfit y_ma y_ma, lwidth(thin) lcolor(black) lpattern(dash)) ///
(scatter y_ma yhat_ma, msymbol(o) mcolor(gs10) msize(medium)) ///
(scatter y_ma yhat_ma if end_recovery_old==1, msymbol(S) mcolor(gs9) msize(large)) ///
(scatter y_ma yhat_ma if end_recovery_new==1, msymbol(O) mcolor(black) msize(large)   ), ///
legend(label(3 "Recoveries before 1990") label(4 "Recoveries after 1990") order(3 4) symxsize(3) cols(2)) ///
title("`title'") ytitle("`ytitle'") xtitle("`xtitle'")  ///
ysize(4) xsize(9.0) ///
plotregion(fcolor(white))  ///
saving(Figure3_changes_MA, replace)
graph export "Figure_3_Changes.png" , replace
restore
*Numbers page 20 Old vs New Recoveries

gen recovery=.
replace recovery =	1	if quarter >= tq(1950q1) & quarter<=tq(1950q4)
replace recovery =	2	if quarter >= tq(1954q3) & quarter<=tq(1955q2)
replace recovery =	3	if quarter >= tq(1958q3) & quarter<=tq(1959q2)
replace recovery =	4	if quarter >= tq(1961q2) & quarter<=tq(1962q1)
replace recovery =	5	if quarter >= tq(1971q1) & quarter<=tq(1971q4)
replace recovery =	6	if quarter >= tq(1975q2) & quarter<=tq(1976q1)
replace recovery =	7	if quarter >= tq(1980q4) & quarter<=tq(1981q3)
replace recovery =	8	if quarter >= tq(1983q1) & quarter<=tq(1983q4)
replace recovery =	9	if quarter >= tq(1991q2) & quarter<=tq(1992q1)
replace recovery =	10	if quarter >= tq(2002q1) & quarter<=tq(2002q4)
replace recovery =	11	if quarter >= tq(2009q3) & quarter<=tq(2010q2)


bys recovery: egen total_emp_g = sum (emp_chg1)
bys recovery: egen total_y_g = sum (y_chg)
gen recovery_old =0
gen recovery_new = 0
replace recovery_old =  1 if quarter >= tq(1950q1) & quarter<=tq(1950q4)
replace recovery_old =  1 if quarter >= tq(1954q3) & quarter<=tq(1955q2)
replace recovery_old =  1 if quarter >= tq(1958q3) & quarter<=tq(1959q2)
replace recovery_old =  1 if quarter >= tq(1961q2) & quarter<=tq(1962q1)
replace recovery_old =  1 if quarter >= tq(1971q1) & quarter<=tq(1971q4)
replace recovery_old =  1 if quarter >= tq(1975q2) & quarter<=tq(1976q1)
replace recovery_old =  1 if quarter >= tq(1980q4) & quarter<=tq(1981q3)
replace recovery_old =  1 if quarter >= tq(1983q1) & quarter<=tq(1983q4)
replace recovery_new =  1 if quarter >= tq(1991q2) & quarter<=tq(1992q1)
replace recovery_new =  1 if quarter >= tq(2002q1) & quarter<=tq(2002q4)
replace recovery_new =  1 if quarter >= tq(2009q3) & quarter<=tq(2010q2)

sum total_y_g total_emp_g if recovery_old
sum total_y_g total_emp_g if recovery_new
