*****************************************************************************************************************
*TABLE 7
*****************************************************************************************************************

* Read in the data

clear all
set more off

cd "$main\data"
use oecd_a_transformed_updated.dta,clear

rename ur_chg u_chg 

* Sample

drop if year>2013
drop if year<1980
* Regressions

cd "$main\outputs"
matrix table_7_L = J(20,8,.)
matrix table_7_C = J(20,8,.)


gen  code = subinstr(country," ","",.)
levelsof code, local(code)
mat rown table_7_L = `code'
mat list table_7_L
mat rown table_7_C = `code'
mat list table_7_C
egen id= group(country) //this is to have an alphabetically ordered list

local var_L = "star100"
local var_C = "chg"
foreach spe in L C {
local i =1
forvalues cty = 1/20{
if "`spe'"=="L"{
reg u_star100 y_star100 if id==`cty' , nocons
} 
if "`spe'"=="C"{
reg u_chg y_chg if id==`cty'
}
local n = e(N)
local l = `n'^(1/4)
local l = round(`l')
matrix table_7_`spe'[`i',8] = e(r2_a)
if "`spe'"=="L"{
newey u_star100 y_star100 if id==`cty' , nocons lag(`l')
lincom _b[y_star100] 
} 
if "`spe'"=="C"{
newey u_chg y_chg if id==`cty' ,  lag(`l')
lincom _b[y_chg] 
}

matrix table_7_`spe'[`i',5] = r(estimate)
matrix table_7_`spe'[`i',7] = r(se)
test _b[y_`var_`spe''] = 0
matrix table_7_`spe'[`i',6]= r(p)
local i = 1 + `i'
}

}
*Quarterly
cd "$main\data"
use oecd_q_transformed_updated.dta,clear
rename ur_chg u_chg 

* Sample

drop if year>2013
drop if year<1980
* Regressions

egen id= group(country)

local var_L = "star1600"
local var_C = "chg"

foreach spe in L C {
local i =1
forvalues cty = 1/20 {
if "`spe'"=="L"{
reg u_star1600 y_star1600 l.y_star1600 l2.y_star1600 if id==`cty' , nocons
}
if "`spe'"=="C"{
reg u_chg y_chg l.y_chg l2.y_chg if id==`cty' 
}
local n = e(N)
local l = `n'^(1/4)
local l = round(`l')
matrix table_7_`spe'[`i',4] = e(r2_a)
if "`spe'"=="L"{
newey u_star1600 y_star1600 l.y_star1600 l2.y_star1600 if id==`cty' , nocons lag(`l')
}
if "`spe'"=="C"{
newey u_chg y_chg l.y_chg l2.y_chg if id==`cty' ,  lag(`l')
}

lincom _b[y_`var_`spe''] +_b[l.y_`var_`spe'']+_b[l2.y_`var_`spe''] 
matrix table_7_`spe'[`i',1] = r(estimate)
matrix table_7_`spe'[`i',3] = r(se)
test _b[y_`var_`spe''] +_b[l.y_`var_`spe'']+_b[l2.y_`var_`spe'']  = 0
matrix table_7_`spe'[`i',2]= r(p)
local i = 1 + `i'
}
preserve
clear
svmat2 table_7_`spe' ,  rnames(country)
rename table_7_`spe'1 coef_q
rename table_7_`spe'2 p_value_q
rename table_7_`spe'3 se_q
rename table_7_`spe'4 adj_r2_q
rename table_7_`spe'5 coef_a
rename table_7_`spe'6 p_value_a
rename table_7_`spe'7 se_a
rename table_7_`spe'8 adj_r2_a
foreach x in a q{
tostring coef_`x' ,replace force format(%4.3f)
replace coef_`x' = coef_`x'+ "***" if p_value_`x'<0.01
replace coef_`x' = coef_`x'+ "**" if p_value_`x'<0.05 & p_value_`x'>=0.01
replace coef_`x' = coef_`x'+ "*" if p_value_`x'<0.1 & p_value_`x'>=0.05
tostring se_`x', replace format(%4.3f) force
replace se_`x' = "("+ se_`x' +")"
drop p_value_`x'
format adj* %4.3f
}
order country
cd "$main\outputs"
export excel using"Table_7", sheet(`spe',replace) first(var)
restore
}
